@@ -1,5 +1,5 @@
 /// This struct represents the coinbase credentials
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct CoinbaseCredentials {
     pub api_key: String,
     pub api_secret: String,
