@@ -4,19 +4,20 @@ use crate::model::websocket::Subscription;
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub enum CoinbaseSubscription {
     Heartbeat(String),
-    Status,
+    // Status,
     // Ticker(String),
     Level2(String),
     // User,
-    // Matches,
+    Matches(String),
     // FullChannel
 }
 
 impl From<Subscription> for CoinbaseSubscription {
     fn from(subscription: Subscription) -> Self {
         match subscription {
-            Subscription::OrderBookUpdates(symbol) => CoinbaseSubscription::Level2(symbol),
-            _ => unimplemented!(),
+            Subscription::OrderBookUpdates(symbol) => CoinbaseSubscription::Level2(crate::exchange::coinbase::model::MarketPair::from(symbol).0),
+            Subscription::Trades(symbol) => CoinbaseSubscription::Matches(crate::exchange::coinbase::model::MarketPair::from(symbol).0),
+            // Subscription::Ticker(ticket) =>
         }
     }
 }
\ No newline at end of file
