@@ -2,8 +2,6 @@
 pub use crate::model::{OrderBookRequest, OrderBookResponse};
 
 pub use crate::exchange::traits::stream::ExchangeWs;
-pub use crate::exchange::traits::info::{ExchangeInfo, ExchangeInfoRetrieval, MarketPair, MarketPairHandle};
+pub use crate::exchange::traits::info::{ExchangeInfo, ExchangeInfoRetrieval, MarketPairInfo, MarketPairHandle};
 pub use crate::exchange::traits::{Exchange, ExchangeAccount, ExchangeMarketData};
-pub use nash_native_client::Environment;
-pub use tokio::time::Duration;
 
